==> 4.7.4.tar.gz: terraform-provider-decort/samples/cloudbroker/kvmvm/data_kvmvm_list/main.tf <==
/*
Пример использования
Получение данных о списке compute (виртуальных машин)
*/

#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      source  = "basis/decort/decort"
      version = "<VERSION>"
    }
  }
}
*/
provider "decort" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "decort_cb_kvmvm_list" "compute_list" {
  #фильтр по id ВМ
  #опциональный параметр
  #тип - целое число
  #by_id = 100

  #фильтр по имени ВМ
  #опциональный параметр
  #тип - строка
  #name = "test"

  #id аккаунта для получения списка ВМ
  #опциональный параметр 
  #тип - целое число
  #account_id = 11111

  #фильтр по имени ресурсной группы
  #опциональный параметр
  #тип - строка
  #rg_name = "test"

  #фильтр по id ресурсной группы
  #опциональный параметр
  #тип - целое число
  #rg_id = 100

  #фильтр по техническому статусу
  #опциональный параметр
  #тип - строка
  #tech_status = "STOPPED"

  #фильтр по статусу
  #опциональный параметр
  #тип - строка
  #status = "ENABLED"

  #фильтр по ip
  #опциональный параметр
  #тип - строка
  #ip_address = "test"

  #фильтр по имени extnet
  #опциональный параметр
  #тип - строка
  #extnet_name = "test"

  #фильтр по id extnet
  #опциональный параметр
  #тип - целое число
  #extnet_id = 100

  #флаг влючения в результат удаленных балансироващиков нагрузки
  #опциональный параметр
  #если не задан - выводятся все доступные неудаленные балансировщики
  #значение по-умолчанию - false
  #тип - булев
  #includedeleted = true

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #тип - строка
  #sort_by = "+name"

  #номер страницы для отображения
  #опциональный параметр
  #если не задан - выводятся все доступные данные
  #тип - целое число
  #page = 1

  #размер страницы
  #опциональный параметр
  #если не задан - выводятся все доступные данные
  #тип - целое число
  #size = 1

}

output "output" {
  value = data.decort_cb_kvmvm_list.compute_list
}

==> 4.9.0.tar.gz: terraform-provider-decort/samples/cloudbroker/kvmvm/data_kvmvm_list/main.tf <==
/*
Пример использования
Получение данных о списке compute (виртуальных машин)
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      source  = "basis/decort/decort"
      version = "<VERSION>"
    }
  }
}
*/
provider "decort" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "decort_cb_kvmvm_list" "compute_list" {
  #фильтр по id ВМ
  #опциональный параметр
  #тип - целое число
  #by_id = 100

  #фильтр по имени ВМ
  #опциональный параметр
  #тип - строка
  #name = "test"

  #id аккаунта для получения списка ВМ
  #опциональный параметр 
  #тип - целое число
  #account_id = 11111

  #фильтр по имени ресурсной группы
  #опциональный параметр
  #тип - строка
  #rg_name = "test"

  #фильтр по id ресурсной группы
  #опциональный параметр
  #тип - целое число
  #rg_id = 100

  #фильтр по техническому статусу
  #опциональный параметр
  #тип - строка
  #tech_status = "STOPPED"

  #фильтр по названию вычислительного узла
  #опциональный параметр
  #тип - строка
  #stack_name = "stack_name"

  #фильтр по статусу
  #опциональный параметр
  #тип - строка
  #status = "ENABLED"

  #фильтр по ip
  #опциональный параметр
  #тип - строка
  #ip_address = "test"

  #фильтр по stack id
  #опциональный параметр
  #тип - целое число
  #stack_id = 123

  #фильтр по image id
  #опциональный параметр
  #тип - целое число
  #image_id = 123

  #фильтр по cd image id
  #опциональный параметр
  #тип - целое число
  #cd_image_id = 123

  #фильтр по имени extnet
  #опциональный параметр
  #тип - строка
  #extnet_name = "test"

  #фильтр по id extnet
  #опциональный параметр
  #тип - целое число
  #extnet_id = 100

  #флаг включения в результат удаленных балансировщиков нагрузки
  #опциональный параметр
  #если не задан - выводятся все доступные неудаленные балансировщики
  #по умолчанию - false
  #тип - булев
  #includedeleted = true

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #тип - строка
  #sort_by = "+name"

  #номер страницы для отображения
  #опциональный параметр
  #если не задан - выводятся все доступные данные
  #тип - целое число
  #page = 1

  #размер страницы
  #опциональный параметр
  #если не задан - выводятся все доступные данные
  #тип - целое число
  #size = 1

}

output "output" {
  value = data.decort_cb_kvmvm_list.compute_list
}
